@@ -1,6 +1,6 @@
 #!/bin/sh
 #set -xv
-UPGRADE_VER="1.0.14"
+UPGRADE_VER="1.0.16"
 TARGET_PREFIX=sp80_upgrade_
 BIN_PATH=/home/root
 CARD_PATH=${MOUNTR}
@@ -510,6 +510,7 @@ fi
 
 # CPU1 upgrade
 SP4LOADER=./${SP4_LOADER_NAME}
+SP4LOADT="-t 20"
 CRC32_EXE=./${CRC32_NAME}
 
 CPU1_BOOT_UPGRADE_FILE=./${CPU1_BOOT_NAME}
@@ -534,16 +535,16 @@ if [ -f ${CPU1_BOOT_UPGRADE_FILE} ]; then
    if [ -f ${CRC32_EXE} ];	then
 			crc=`${CRC32_EXE} ${CPU1_BOOT_UPGRADE_FILE}`
             echo "${CPU1_BOOT_UPGRADE_FILE} crc ${crc}" | tee -a ${LOG}
-   		    ${SP4LOADER} -u -f ${CPU1_BOOT_UPGRADE_FILE} -p /dev/ttySP1 -c ${crc} 2>&1
+   		    ${SP4LOADER} ${SP4LOADT} -u -f ${CPU1_BOOT_UPGRADE_FILE} -p /dev/ttySP1 -c ${crc} 2>&1
         else
-   		    ${SP4LOADER} -u -f ${CPU1_BOOT_UPGRADE_FILE} -p /dev/ttySP1 2>&1
+   		    ${SP4LOADER} ${SP4LOADT} -u -f ${CPU1_BOOT_UPGRADE_FILE} -p /dev/ttySP1 2>&1
         fi
 		if [ ! $? -eq 0 ]; then
 			echo "Error to upgrade CPU1 u-boot. Repeat" | tee -a ${LOG}
             echo "=== cpu1_deb.log start ===" | tee -a ${LOG}
 	    	cat ./cpu1_deb.log >> ${LOG}
             echo "=== cpu1_deb.log stop ===" | tee -a ${LOG}
-   		    ${SP4LOADER} -u -r -f ${CPU1_BOOT_UPGRADE_FILE} -p /dev/ttySP1 2>&1
+   		    ${SP4LOADER} ${SP4LOADT} -u -r -f ${CPU1_BOOT_UPGRADE_FILE} -p /dev/ttySP1 2>&1
         fi
 		if [ ! $? -eq 0 ]; then
 			echo "Error to upgrade CPU1 u-boot !!!" | tee -a ${LOG}
@@ -574,16 +575,16 @@ if [ -f ${CPU1_XLDR_NAME} ]; then
    if [ -f ${CRC32_EXE} ]; then
 			crc=`${CRC32_EXE} ${CPU1_XLDR_NAME}`
             echo "${CPU1_XLDR_NAME} crc ${crc}" | tee -a ${LOG}
-   		    ${SP4LOADER} -x -f ${CPU1_XLDR_NAME} -p /dev/ttySP1 -c ${crc} 2>&1
+   		    ${SP4LOADER} ${SP4LOADT} -x -f ${CPU1_XLDR_NAME} -p /dev/ttySP1 -c ${crc} 2>&1
         else
-   		    ${SP4LOADER} -x -f ${CPU1_XLDR_NAME} -p /dev/ttySP1 2>&1
+   		    ${SP4LOADER} ${SP4LOADT} -x -f ${CPU1_XLDR_NAME} -p /dev/ttySP1 2>&1
         fi
 		if [ ! $? -eq 0 ]; then
 			echo "Error to upgrade CPU1 ${CPU1_XLDR_NAME}. Repeat" | tee -a ${LOG}
             echo "=== cpu1_deb.log start ===" | tee -a ${LOG}
 	    	cat ./cpu1_deb.log >> ${LOG}
             echo "=== cpu1_deb.log stop ===" | tee -a ${LOG}
-   		    ${SP4LOADER} -x -r -f ${CPU1_XLDR_NAME} -p /dev/ttySP1 2>&1
+   		    ${SP4LOADER} ${SP4LOADT} -x -r -f ${CPU1_XLDR_NAME} -p /dev/ttySP1 2>&1
         fi
 		if [ ! $? -eq 0 ]; then
 			echo "Error to upgrade CPU1 ${CPU1_XLDR_NAME} !!!" | tee -a ${LOG}
@@ -618,9 +619,9 @@ then
 			crc=`${CRC32_EXE} ${G5_UPGRADE_FILE}`
             echo "${G5_UPGRADE_FILE} crc ${crc}" | tee -a ${LOG}
             fs_flush
-		    ${SP4LOADER} -f ${G5_UPGRADE_FILE} -p /dev/ttySP1 -c ${crc} 2>&1
+		    ${SP4LOADER} ${SP4LOADT} -f ${G5_UPGRADE_FILE} -p /dev/ttySP1 -c ${crc} 2>&1
         else
-		    ${SP4LOADER} -f ${G5_UPGRADE_FILE} -p /dev/ttySP1 > /dev/null 2>&1
+		    ${SP4LOADER} ${SP4LOADT} -f ${G5_UPGRADE_FILE} -p /dev/ttySP1 > /dev/null 2>&1
         fi
 		if [ ! $? -eq 0 ]; then
 			echo "Error to upgrade G5. Repeat" | tee -a ${LOG}
@@ -628,7 +629,7 @@ then
 	    	cat ./cpu1_deb.log >> ${LOG}
             echo "=== cpu1_deb.log stop ===" | tee -a ${LOG}
             fs_flush
-		    ${SP4LOADER} -r -f ${G5_UPGRADE_FILE} -p /dev/ttySP1 > /dev/null 2>&1
+		    ${SP4LOADER} ${SP4LOADT} -r -f ${G5_UPGRADE_FILE} -p /dev/ttySP1 > /dev/null 2>&1
         fi
 		if [ ! $? -eq 0 ]; then
 			echo "Error to upgrade G5 !!!" | tee -a ${LOG}
@@ -662,7 +663,7 @@ then
 
         check_gnss ${CPU1_XLDR_NAME}
         check_gnss ${SP4_LOADER_NAME}
-		${SP4LOADER} -x -f ${CPU1_XLDR_UPGRADE_FILE} -p /dev/ttySP1 >> ./g5.log 2>&1
+		${SP4LOADER} ${SP4LOADT} -x -f ${CPU1_XLDR_UPGRADE_FILE} -p /dev/ttySP1 >> ./g5.log 2>&1
 		if [ ! $? -eq 0 ];
 		then
             displ "Error 8.3"
@@ -720,6 +721,11 @@ cd ${BIN_PATH}
 tar -x${TAR_OPT} ${TAR_FILE} productVersion.txt
 new_ver=$(cat productVersion.txt)
 
+echo "Removing prev.data" | tee -a ${LOG}
+fs_flush
+rm -rf /mnt/pvt/antenna
+sync
+
 cd ${RAM_PATH}
 echo "Product version ${new_ver}"  | tee -a ${LOG}
 echo "End upgrade script at " $(date) | tee -a ${LOG}
